==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/processing/src/main/java/org/apache/druid/query/filter/DruidDoublePredicate.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query.filter;

/**
 * Note: this is not a {@link org.apache.druid.guice.annotations.PublicApi} or an
 * {@link org.apache.druid.guice.annotations.ExtensionPoint} of Druid.
 */
// All implementations are currently lambda expressions and intellij inspections wrongly complains about unused
// variable. SupressWarnings can be removed once https://youtrack.jetbrains.com/issue/IDEA-191743 is resolved.
@SuppressWarnings("unused")
public interface DruidDoublePredicate
{
  DruidDoublePredicate ALWAYS_FALSE = input -> false;

  DruidDoublePredicate ALWAYS_TRUE = input -> true;

  DruidDoublePredicate MATCH_NULL_ONLY = new DruidDoublePredicate()
  {
    @Override
    public boolean applyDouble(double input)
    {
      return false;
    }

    @Override
    public boolean applyNull()
    {
      return true;
    }
  };

  boolean applyDouble(double input);

  default boolean applyNull()
  {
    return false;
  }
}

==> apache-druid-33.0.0-src.tar.gz: apache-druid-33.0.0-src/processing/src/main/java/org/apache/druid/query/filter/DruidDoublePredicate.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query.filter;

/**
 * Note: this is not a {@link org.apache.druid.guice.annotations.PublicApi} or an
 * {@link org.apache.druid.guice.annotations.ExtensionPoint} of Druid.
 */
// All implementations are currently lambda expressions and intellij inspections wrongly complains about unused
// variable. SupressWarnings can be removed once https://youtrack.jetbrains.com/issue/IDEA-191743 is resolved.
@SuppressWarnings("unused")
public interface DruidDoublePredicate
{
  DruidDoublePredicate ALWAYS_FALSE_WITH_NULL_UNKNOWN = input -> DruidPredicateMatch.FALSE;

  DruidDoublePredicate ALWAYS_TRUE = input -> DruidPredicateMatch.TRUE;

  DruidDoublePredicate MATCH_NULL_ONLY = new DruidDoublePredicate()
  {
    @Override
    public DruidPredicateMatch applyDouble(double input)
    {
      return DruidPredicateMatch.FALSE;
    }

    @Override
    public DruidPredicateMatch applyNull()
    {
      return DruidPredicateMatch.TRUE;
    }
  };

  DruidPredicateMatch applyDouble(double input);

  default DruidPredicateMatch applyNull()
  {
    return DruidPredicateMatch.UNKNOWN;
  }
}
